@@ -10,16 +10,15 @@ use Exporter qw(import);
 use Hash::MultiValue;
 use HTTP::Response;
 use HTTP::Tiny;
-use Params::ValidationCompiler qw( validation_for );
+use Params::ValidationCompiler qw(validation_for);
+use Test::BDD::Cucumber::Definitions qw(S);
 use Test::BDD::Cucumber::Definitions::TypeConstraints qw(:all);
-use Test::BDD::Cucumber::StepFile qw();
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 our @EXPORT_OK = qw(
-    S C
     request_send
     code_eq
     header_set header_eq header_re
@@ -44,9 +43,6 @@ const my $HTTP_INTERNAL_EXCEPTION => 599;
 
 ## no critic [Subroutines::RequireArgUnpacking]
 
-sub S { return Test::BDD::Cucumber::StepFile::S }
-sub C { return Test::BDD::Cucumber::StepFile::C }
-
 my $validator_header_set = validation_for(
     params => [
 
