@@ -7,15 +7,15 @@ use Carp;
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
 use JSON::XS;
-use Params::ValidationCompiler qw( validation_for );
+use Params::ValidationCompiler qw(validation_for);
+use Test::BDD::Cucumber::Definitions qw(S);
 use Test::BDD::Cucumber::Definitions::TypeConstraints qw(:all);
-use Test::BDD::Cucumber::StepFile qw();
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
-our @EXPORT_OK = qw(S C
+our @EXPORT_OK = qw(
     content_decode
 );
 our %EXPORT_TAGS = (
@@ -28,19 +28,16 @@ our %EXPORT_TAGS = (
 
 ## no critic [Subroutines::RequireArgUnpacking]
 
-sub S { return Test::BDD::Cucumber::StepFile::S }
-sub C { return Test::BDD::Cucumber::StepFile::C }
-
 sub content_decode {
 
     # Clean data structure
-    S->{data}->{structure} = undef;
+    S->{struct}->{data} = undef;
 
     my $error;
 
     my $decoded_content = S->{http}->{response_object}->decoded_content();
 
-    S->{data}->{structure} = try {
+    S->{struct}->{data} = try {
         decode_json($decoded_content);
     }
     catch {
