@@ -3,10 +3,10 @@ package Test::BDD::Cucumber::Definitions::JSON::In;
 use strict;
 use warnings;
 
-use Test::BDD::Cucumber::StepFile qw(Given When Then);
+use Test::BDD::Cucumber::Definitions qw(Given When Then);
 use Test::BDD::Cucumber::Definitions::JSON qw(:util);
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
