@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use utf8;
 
-use Test::BDD::Cucumber::StepFile qw(Given When Then);
+use Test::BDD::Cucumber::Definitions qw(Given When Then);
 use Test::BDD::Cucumber::Definitions::JSON qw(:util);
 
 =encoding utf8
@@ -16,7 +16,7 @@ Test::BDD::Cucumber::Definitions::JSON::Ru - Шаги на русском язы
 
 =cut
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
