@@ -7,14 +7,14 @@ use Carp;
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
 use JSON::Path 'jpath1';
-use Params::ValidationCompiler qw( validation_for );
+use Params::ValidationCompiler qw(validation_for);
+use Test::BDD::Cucumber::Definitions qw(S);
 use Test::BDD::Cucumber::Definitions::TypeConstraints qw(:all);
-use Test::BDD::Cucumber::StepFile qw();
 use Test::More;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
-our @EXPORT_OK = qw(S C
+our @EXPORT_OK = qw(
     jsonpath_eq jsonpath_re
 );
 our %EXPORT_TAGS = (
@@ -30,9 +30,6 @@ $JSON::Path::Safe = 0;    ## no critic (Variables::ProhibitPackageVars)
 
 ## no critic [Subroutines::RequireArgUnpacking]
 
-sub S { return Test::BDD::Cucumber::StepFile::S }
-sub C { return Test::BDD::Cucumber::StepFile::C }
-
 my $validator_jsonpath_eq = validation_for(
     params => [
 
@@ -47,11 +44,11 @@ my $validator_jsonpath_eq = validation_for(
 sub jsonpath_eq {
     my ( $jsonpath, $value ) = $validator_jsonpath_eq->(@_);
 
-    my $result = jpath1( S->{data}->{structure}, $jsonpath );
+    my $result = jpath1( S->{struct}->{data}, $jsonpath );
 
     is( $result, $value, qq{Data structure jsonpath "$jsonpath" eq "$value"} );
 
-    diag( 'Data structure = ' . np S->{data}->{structure} );
+    diag( 'Data structure = ' . np S->{struct}->{data} );
 
     return;
 }
@@ -70,7 +67,7 @@ my $validator_jsonpath_re = validation_for(
 sub jsonpath_re {
     my ( $jsonpath, $regexp ) = $validator_jsonpath_re->(@_);
 
-    my $result = jpath1( S->{data}->{structure}, $jsonpath );
+    my $result = jpath1( S->{struct}->{data}, $jsonpath );
 
     like(
         $result,
@@ -78,7 +75,7 @@ sub jsonpath_re {
         qq{Data structure jsonpath "$jsonpath" re "$regexp"}
     );
 
-    diag( 'Data structure = ' . np S->{data}->{structure} );
+    diag( 'Data structure = ' . np S->{struct}->{data} );
 
     return;
 }
